summaryrefslogtreecommitdiff
path: root/src/python/gudhi/alpha_complex.pyx
diff options
context:
space:
mode:
authorROUVREAU Vincent <vincent.rouvreau@inria.fr>2020-06-05 18:44:17 +0200
committerROUVREAU Vincent <vincent.rouvreau@inria.fr>2020-06-05 18:44:17 +0200
commit4f02ba9c5a3233ff9d4554578fbe3ae456b9711f (patch)
treee330fa1a9781d73fa497ef56d791162d1bf65a87 /src/python/gudhi/alpha_complex.pyx
parente7ccfabc395352823c0330ef876b9ac0ef72e840 (diff)
code review: rename complexity with precision
Diffstat (limited to 'src/python/gudhi/alpha_complex.pyx')
-rw-r--r--src/python/gudhi/alpha_complex.pyx14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/python/gudhi/alpha_complex.pyx b/src/python/gudhi/alpha_complex.pyx
index 3855f1ac..d9c2be81 100644
--- a/src/python/gudhi/alpha_complex.pyx
+++ b/src/python/gudhi/alpha_complex.pyx
@@ -57,7 +57,7 @@ cdef class AlphaComplex:
cdef bool exact
# Fake constructor that does nothing but documenting the constructor
- def __init__(self, points=None, off_file='', complexity='safe'):
+ def __init__(self, points=None, off_file='', precision='safe'):
"""AlphaComplex constructor.
:param points: A list of points in d-Dimension.
@@ -68,15 +68,15 @@ cdef class AlphaComplex:
:param off_file: An OFF file style name.
:type off_file: string
:param complexity: Alpha complex complexity can be 'fast', 'safe' or 'exact'. Default is 'safe'.
:type complexity: string
"""
# The real cython constructor
- def __cinit__(self, points = None, off_file = '', complexity = 'safe'):
- assert complexity in ['fast', 'safe', 'exact'], "Alpha complex complexity can only be 'fast', 'safe' or 'exact'"
- cdef bool fast = complexity == 'fast'
- self.exact = complexity == 'safe'
+ def __cinit__(self, points = None, off_file = '', precision = 'safe'):
+ assert precision in ['fast', 'safe', 'exact'], "Alpha complex precision can only be 'fast', 'safe' or 'exact'"
+ cdef bool fast = precision == 'fast'
+ self.exact = precision == 'safe'
cdef vector[vector[double]] pts
if off_file:
@@ -68,15 +68,15 @@ cdef class AlphaComplex:
:param off_file: An OFF file style name.
:type off_file: string
- :param complexity: Alpha complex complexity can be 'fast', 'safe' or 'exact'. Default is 'safe'.
- :type complexity: string
+ :param precision: Alpha complex precision can be 'fast', 'safe' or 'exact'. Default is 'safe'.
+ :type precision: string
"""
# The real cython constructor